window.onload = function () {
  var spread = new GC.Spread.Sheets.Workbook(document.getElementById("ss"), {
    sheetCount: 0,
  });
  initSpread(spread);
};

let disableRows = new Set([0,1])

let oldOpenDateTimeCmd = GC.Spread.Sheets.Commands.openDateTimePicker.execute;
GC.Spread.Sheets.Commands.openDateTimePicker.execute = function () {
  let options = arguments[1]
  if (disableRows.has(options.row)) return false;
  return oldOpenDateTimeCmd.apply(this, arguments)
}

function initSpread(spread) {
  spread.suspendPaint();
  spread.options.autoFitType = GC.Spread.Sheets.AutoFitType.cellWithHeader;
  var dataManager = spread.dataManager();
  initDefineOrderTable(spread, dataManager);
  spread.resumePaint();
}

function initDefineOrderTable(spread, dataManager) {
  spread.options.allowDynamicArray = true;

  // Define the date validator
  // const dateValidator = {
  //     comparisonOperator: GC.Spread.Sheets.ConditionalFormatting.ComparisonOperators.between,
  //     type: "date",
  //     value1: new Date(2024, 11, 20), // Start date: Dec 20, 2024
  //     value2: new Date(2024, 11, 25), // End date: Dec 25, 2024
  //     inputTitle: "Date Validation",
  //     inputMessage: "Enter a date between December 20, 2024, and December 25, 2024",
  // };
  const dateValidator = (minDate, maxDate) => {
    return {
      type: 'date',
      comparisonOperator: 'between',
      value1: minDate,
      value2: maxDate,
      errorMessage: "Error Invalid date",
      errorStyle: 'stop',
      highlightStyle: {
        type: 'dogEar',
        color: 'red',
        position: 'topLeft'
      },
      ignoreBlank: false,
      inCellDropdown: false,
      errorTitle: '',
      inputMessage: '',
      inputTitle: '',
      showErrorMessage: true,
      showInputMessage: false
    }
  }

  var orderTable = dataManager.addTable("orderTable", {
    data: [
      {
        description: "Mow grass",
        dueDate: undefined,
        priority: "High",
        assignedTo: "Dad",
        isFinished: "Yes",
        isEncouraged: "False",
        credit: "20,75",
      },
      {
        description: "Clean Room",
        dueDate: "8/9/2021",
        priority: "Medium",
        assignedTo: "Daughter",
        isFinished: "No",
        isEncouraged: "True",
        credit: "10,50",
      },
      {
        description: "Organize Pantry",
        dueDate: new Date(2024, 11, 20),
        priority: "Low",
        assignedTo: "Son",
        isFinished: "Yes",
        isEncouraged: "True",
        credit: "10,75",
      },
      {
        description: "Prepare BBQ",
        dueDate: "22/12/2024",
        priority: "High",
        assignedTo: "Mom",
        isFinished: "No",
        isEncouraged: "False",
        credit: "30,25",
      },
    ],
    schema: {
      columns: {
        dueDate: { dataType: "date", dataPattern: "yyyy/mm/dd" },
        isFinished: { dataPattern: "Yes|No" },
        isEncouraged: { dataType: "boolean", dataPattern: "True|False" },
        credit: { dataType: "number", dataPattern: "." },
      },
    },
  });

  var tableSheet = spread.addSheetTab(
    0,
    "Orders",
    GC.Spread.Sheets.SheetType.tableSheet
  );
  tableSheet.options.allowAddNew = true;
  tableSheet.options.enableDefineColumn = true;

  //add the validation result to discard in case the validation fails
  tableSheet.bind(GC.Spread.Sheets.Events.ValidationError, function (e, args) {
    console.log(args)
    args.validationResult = GC.Spread.Sheets.DataValidation.DataValidationResult.discard;
  });

  //   tableSheet.bind(GC.Spread.Sheets.Events.EditStarting, function (e, args) {
  //     console.log(e,args);

  //     if (args.row === 3) { //disabling the 3 row
  //         args.cancel = true; // Cancel the edit action
  //     }
  // });

  var orderView = orderTable.addView("orderView", [
    { value: "description", width: 80 },
    //date-time-picker-column
    {
      value: "dueDate",
      dataType: "date",
      width: 150,
      style: {
        formatter: "yyyy/mm/dd",
        hAlign: "left"
      },
      validator: dateValidator(new Date(2024, 11, 20), new Date(2024, 11, 25)),
    },
    { value: "priority", width: 80 },
    { value: "assignedTo", width: 80 },
    { value: "isFinished", width: 80 },
    { value: "isEncouraged", width: 80 },
    { value: "credit", width: 80 },
  ]);

  orderView.fetch().then(function () {
    tableSheet.setDataView(orderView);
  });
}
